#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for Unicode Indic True Type Fonts

#---( This is a collection of Unicode Indian language True Type Fonts
#---( Fonts in Source1 have been taken from Debian Project.
#---( Source1 URL: http://ftp.de.debian.org/debian/pool/main/t/ttf-indic-fonts/ttf-indic-fonts_0.5.6.tar.gz

#---( Author: R S Ananda Murthy (rsamurti@gmail.com)
#---( Date build script was last modified: Monday, March 17, 2008


#------------------( Set Package Name & Version )


soft='ttf-indic-fonts'
softversion='0.5.6'
packageversion='62.1'
sourcetemplate='http://zenwalk.pinguix.com/user-accounts/rsamurti/ttf-indic-fonts'


#------------------( Check for source files )


if [ -f ttf-indic-fonts_$softversion.tar.gz  ]; then
   echo "Source1 file .. ok"
else
   echo "Source1 file does not exit. Downloading it ..."
   wget -c http://ftp.de.debian.org/debian/pool/main/t/ttf-indic-fonts/ttf-indic-fonts_$softversion.tar.gz 
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='noarch'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/ttf-indic-fonts_$softversion.tar.gz"
src="$buildir/ttf-indic-fonts-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships )


chown -R root:root .



#------------------( Move Fonts To Correct Location )


cd $src
mkdir -p $dest/usr/share/fonts/TTF
mv -t $dest/usr/share/fonts/TTF ttf-bengali
mv -t $dest/usr/share/fonts/TTF ttf-devanagari 
mv -t $dest/usr/share/fonts/TTF ttf-kannada
mv -t $dest/usr/share/fonts/TTF ttf-oriya
mv -t $dest/usr/share/fonts/TTF ttf-tamil
mv -t $dest/usr/share/fonts/TTF ttf-gujarati
mv -t $dest/usr/share/fonts/TTF ttf-malayalam
mv -t $dest/usr/share/fonts/TTF ttf-telugu
mv -t $dest/usr/share/fonts/TTF ttf-punjabi


#------------------( Move Licenses To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a ./debian/*.copyright $dest/usr/doc/$soft-$softversion

cat <<EOF > $dest/usr/doc/$soft-$softversion/COPYING
All the fonts in this package are free as per GPL.
EOF


#------------------( Copy The Build Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
               |-----handy-ruler------------------------------------------------------|
ttf-indic-fonts: ttf-indic-fonts (Unicode True Type Fonts for Indian languages)
ttf-indic-fonts:
ttf-indic-fonts: This package contains free true type fonts for Indian languages.
ttf-indic-fonts: Users can suggest additional fonts which can be included in this
ttf-indic-fonts: package. This package contains Indic fonts taken from a similar
ttf-indic-fonts: Debian package and some additional free fonts.
ttf-indic-fonts: 
ttf-indic-fonts: 
ttf-indic-fonts: 
ttf-indic-fonts: 
ttf-indic-fonts: 
EOF


#------------------( Create The SRC File )


if [ -f $buildir/$package.src  ]; then
rm $package.src
fi
cat <<EOF > $buildir/$package.src
$sourcetemplate/build-$soft.sh
$sourcetemplate/$soft_$softversion.tar.gz
EOF



#------------------( Create The Doinst.sh )


cat <<EOF > $dest/install/doinst.sh
if [ -x /usr/bin/fc-cache ]; then
  /usr/bin/fc-cache -f
fi
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 770 -exec chmod 755 {} \;
find . -perm 700 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$package.tlz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tlz > $package.md5
zen-pkgcheck.pl $package.tlz
depfinder -f $package.tlz
